| Copyright | (C) 2017 Jason Johnson |
|---|---|
| License | BSD-style (see the file LICENSE) |
| Maintainer | Jason Johnson <jason.johnson.081@gmail.com> |
| Stability | experimental |
| Portability | POSIX, Windows |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Data.HodaTime.Calendar.Coptic
Contents
Description
This is the module for CalendarDate and CalendarDateTime in the Coptic calendar, the liturgical calendar of the Coptic Orthodox Church whose era of the Martyrs (Anno Martyrum) counts years
from AD 284. The year is twelve months of 30 days followed by a short thirteenth month (PiKogiEnavot, the epagomenal days) of five days, or six in a leap year. Leap years follow the same simple
every-fourth-year rule as Julian (a Coptic year is leap when year `mod` 4 == 3), with the extra day added at the end of the year. Year 1 begins on 29.Aug.284 in the
Julian calendar; dates share the same absolute timeline as every other calendar.
Synopsis
- calendarDate :: DayOfMonth -> Month Coptic -> Year -> Maybe (CalendarDate Coptic)
- fromNthDay :: DayNth -> DayOfWeek Coptic -> Month Coptic -> Year -> Maybe (CalendarDate Coptic)
- fromWeekDate :: WeekNumber -> DayOfWeek Coptic -> Year -> Maybe (CalendarDate Coptic)
- data family Month cal
- data family DayOfWeek cal
- data Coptic
Constructors
calendarDate :: DayOfMonth -> Month Coptic -> Year -> Maybe (CalendarDate Coptic) Source #
Smart constructor for a Coptic calendar date.
fromNthDay :: DayNth -> DayOfWeek Coptic -> Month Coptic -> Year -> Maybe (CalendarDate Coptic) Source #
fromWeekDate :: WeekNumber -> DayOfWeek Coptic -> Year -> Maybe (CalendarDate Coptic) Source #
Smart constructor for a Coptic calendar date given as a week date. Note that this method assumes weeks start on Sunday and the first week of the year is the one
which has at least one day in the new year.
Types
data family Month cal Source #
Instances
data family DayOfWeek cal Source #