hodatime
Copyright(C) 2016 Jason Johnson
LicenseBSD-style (see the file LICENSE)
MaintainerJason Johnson <jason.johnson.081@gmail.com>
Stabilityexperimental
PortabilityPOSIX, Windows
Safe HaskellSafe-Inferred
LanguageHaskell2010

Data.HodaTime.OffsetDateTime

Description

An OffsetDateTime is a date and time combined with an offset from UTC time. OffsetDateTime is the form that HTTP uses to deal with dates and times.

Synopsis

Types

data OffsetDateTime cal Source #

A CalendarDateTime with a UTC offset. This is the format used by e.g. HTTP. This type has a fixed TimeZone with the name "UTC(+/-)offset". If the offset is empty, the name of the TimeZone will be UTC

Instances

Instances details
IsCalendarDateTime cal => Show (OffsetDateTime cal) Source #

Renders an OffsetDateTime as the fromInstantWithOffset call that reconstructs it.

Instance details

Defined in Data.HodaTime.OffsetDateTime

Eq (Date cal) => Eq (OffsetDateTime cal) Source # 
Instance details

Defined in Data.HodaTime.OffsetDateTime

(IsCalendarDateTime cal, Eq (Date cal)) => Ord (OffsetDateTime cal) Source # 
Instance details

Defined in Data.HodaTime.OffsetDateTime

Hashable (Date cal) => Hashable (OffsetDateTime cal) Source # 
Instance details

Defined in Data.HodaTime.OffsetDateTime

Methods

hashWithSalt :: Int -> OffsetDateTime cal -> Int #

hash :: OffsetDateTime cal -> Int #

Constructors

fromInstantWithOffset :: IsCalendarDateTime cal => Instant -> Offset -> OffsetDateTime cal Source #

Create an OffsetDateTime from an Instant and an Offset.

Math

Conversion

toCalendarDateTime :: OffsetDateTime cal -> CalendarDateTime cal Source #

The local (wall-clock) CalendarDateTime of the OffsetDateTime, before the offset is applied.