hodatime
Copyright(C) 2017 Jason Johnson
LicenseBSD-style (see the file LICENSE)
MaintainerJason Johnson <jason.johnson.081@gmail.com>
Stabilityexperimental
PortabilityPOSIX, Windows
Safe HaskellSafe-Inferred
LanguageHaskell2010

Data.HodaTime.Pattern.CalendarDateTime

Description

Patterns for a CalendarDateTime: the combined date-and-time layouts (ps, po, pf/pF, pg/pG), each of which glues a date pattern to a time pattern.

Synopsis

Standard Patterns

ps :: (HasLocalTime dt, HasDate dt, Enum (MoY dt)) => Pattern (dt -> dt) (dt -> String) String Source #

The sortable pattern, which is always "yyyy-MM-ddT'HH:mm:'ss". (Note: this is only truly sortable for years within the range [0-9999].)

po :: (HasLocalTime dt, HasDate dt, Enum (MoY dt)) => Pattern (dt -> dt) (dt -> String) String Source #

The ISO-8601 round-trippable date/time pattern, "yyyy-MM-ddT'HH:mm:ss.'fffffffff" (nanosecond precision).

pf :: (HasLocalTime (c cal), HasDate (c cal), MoY (c cal) ~ Month cal, IsCalendar cal, Bounded (Month cal), Read (Month cal), Show (Month cal), Enum (Month cal), Show (DoW (c cal)), Enum (DoW (c cal)), Bounded (DoW (c cal))) => Pattern (c cal -> c cal) (c cal -> String) String Source #

The long date pattern followed by a space, followed by the short time pattern.

pF :: (HasLocalTime (c cal), HasDate (c cal), MoY (c cal) ~ Month cal, IsCalendar cal, Bounded (Month cal), Read (Month cal), Show (Month cal), Enum (Month cal), Show (DoW (c cal)), Enum (DoW (c cal)), Bounded (DoW (c cal))) => Pattern (c cal -> c cal) (c cal -> String) String Source #

The full date and time pattern. This is currently "dddd, dd MMMM yyyy HH:mm:ss".

pg :: (HasLocalTime dt, HasDate dt, Enum (MoY dt)) => Pattern (dt -> dt) (dt -> String) String Source #

The short date pattern followed by a space, followed by the short time pattern.

pG :: (HasLocalTime dt, HasDate dt, Enum (MoY dt)) => Pattern (dt -> dt) (dt -> String) String Source #

The short date pattern followed by a space, followed by the long time pattern.

Custom Patterns

Use combination of CalendarDate and LocalTime patterns