hodatime
Copyright(C) 2017 Jason Johnson
LicenseBSD-style (see the file LICENSE)
MaintainerJason Johnson <jason.johnson.081@gmail.com>
Stabilityexperimental
PortabilityPOSIX, Windows
Safe HaskellSafe-Inferred
LanguageHaskell2010

Data.HodaTime.TimeZone

Description

This module deals with loading TimeZone information with which to construct ZonedDateTimes.

Synopsis

Types

data TimeZone Source #

Represents a time zone. A TimeZone can be used to instanciate a ZoneDateTime from either and Instant or a CalendarDateTime

Instances

Instances details
Show TimeZone Source #

Shows a TimeZone by its identity only (the transition maps are a derived cache, not part of identity).

Instance details

Defined in Data.HodaTime.TimeZone.Internal

Eq TimeZone Source #

Two TimeZones are equal when they denote the same zone (compared by identifier). The transition maps are a derived lookup cache fully determined by the identifier, so they are not part of the zone's identity.

Instance details

Defined in Data.HodaTime.TimeZone.Internal

Hashable TimeZone Source # 
Instance details

Defined in Data.HodaTime.TimeZone.Internal

Methods

hashWithSalt :: Int -> TimeZone -> Int #

hash :: TimeZone -> Int #

Constructors

utc :: IO TimeZone Source #

Load the UTC time zone

localZone :: IO TimeZone Source #

Load the locally configured time zone (operating system configuration dependant)

timeZone :: String -> IO TimeZone Source #

Load the specified time zone. The time zone name should be in the format returned by availableZones

availableZones :: IO [String] Source #

List all time zones available to hodatime